==> hypersistence-utils-hibernate-52-3.7.6-sources.jar: io/hypersistence/utils/hibernate/type/array/FloatArrayType.java <==
package io.hypersistence.utils.hibernate.type.array;

import io.hypersistence.utils.hibernate.type.array.internal.AbstractArrayType;
import io.hypersistence.utils.hibernate.type.array.internal.FloatArrayTypeDescriptor;
import io.hypersistence.utils.hibernate.type.util.Configuration;
import io.hypersistence.utils.hibernate.type.util.ParameterizedParameterType;
import org.hibernate.usertype.DynamicParameterizedType;

import java.util.Properties;

/**
 * Maps a {@code float[]} array on a PostgreSQL ARRAY type. Multidimensional arrays are supported as well, as explained in <a href="https://vladmihalcea.com/multidimensional-array-jpa-hibernate/">this article</a>.
 * <p>
 * For more details about how to use it, check out <a href=
 * "https://vladmihalcea.com/how-to-map-java-and-sql-arrays-with-jpa-and-hibernate/">this
 * article</a> on <a href="https://vladmihalcea.com/">vladmihalcea.com</a>.
 *
 * @author Vlad Mihalcea
 * @author Andreas Eberle
 */
public class FloatArrayType extends AbstractArrayType<float[]> {

    public static final FloatArrayType INSTANCE = new FloatArrayType();

    public FloatArrayType() {
        super(
            new FloatArrayTypeDescriptor()
        );
    }

    public FloatArrayType(Configuration configuration) {
        super(
            new FloatArrayTypeDescriptor(),
            configuration
        );
    }

    public FloatArrayType(Class arrayClass) {
        this();
        Properties parameters = new Properties();
        parameters.put(DynamicParameterizedType.PARAMETER_TYPE, new ParameterizedParameterType(arrayClass));
        setParameterValues(parameters);
    }

    @Override
    public String getName() {
        return "float-array";
    }
}

==> hypersistence-utils-hibernate-63-3.9.2-sources.jar: io/hypersistence/utils/hibernate/type/array/FloatArrayType.java <==
package io.hypersistence.utils.hibernate.type.array;

import io.hypersistence.utils.hibernate.type.array.internal.AbstractArrayType;
import io.hypersistence.utils.hibernate.type.array.internal.FloatArrayTypeDescriptor;
import io.hypersistence.utils.hibernate.type.util.Configuration;
import io.hypersistence.utils.hibernate.type.util.ParameterizedParameterType;
import org.hibernate.usertype.DynamicParameterizedType;

import java.util.Properties;

/**
 * Maps a {@code float[]} array on a PostgreSQL ARRAY type. Multidimensional arrays are supported as well, as explained in <a href="https://vladmihalcea.com/multidimensional-array-jpa-hibernate/">this article</a>.
 * <p>
 * For more details about how to use it, check out <a href=
 * "https://vladmihalcea.com/how-to-map-java-and-sql-arrays-with-jpa-and-hibernate/">this
 * article</a> on <a href="https://vladmihalcea.com/">vladmihalcea.com</a>.
 *
 * @author Vlad Mihalcea
 * @author Andreas Eberle
 */
public class FloatArrayType extends AbstractArrayType<float[]> {

    public static final FloatArrayType INSTANCE = new FloatArrayType();

    public FloatArrayType() {
        super(
            new FloatArrayTypeDescriptor()
        );
    }

    public FloatArrayType(Configuration configuration) {
        super(
            new FloatArrayTypeDescriptor(),
            configuration
        );
    }

    public FloatArrayType(Class arrayClass) {
        this();
        Properties parameters = new Properties();
        parameters.put(DynamicParameterizedType.PARAMETER_TYPE, new ParameterizedParameterType(arrayClass));
        setParameterValues(parameters);
    }

    public FloatArrayType(org.hibernate.type.spi.TypeBootstrapContext typeBootstrapContext) {
        this(new Configuration(typeBootstrapContext.getConfigurationSettings()));
    }

    public String getName() {
        return "float-array";
    }
}
